var vsttypes_8h =
[
    [ "kVstVersionString", "vsttypes_8h.html#aced0665aaa99dc2ccc0a6b793710f60b", null ],
    [ "kVstVersionMajor", "vsttypes_8h.html#a307b16bcbe3263db838d1a65a1590775", null ],
    [ "kVstVersionMinor", "vsttypes_8h.html#aad745365073e680343605ac17c381811", null ],
    [ "kVstVersionSub", "vsttypes_8h.html#a6e91d244c8cfdd2b123d37e599043ca1", null ],
    [ "VST_VERSION", "vsttypes_8h.html#a8f8e3e0f6ff1889cda8597884edccb61", null ],
    [ "VST_3_7_12_VERSION", "vsttypes_8h.html#a79417033b8926d7da1e79f901ed7b739", null ],
    [ "VST_3_7_11_VERSION", "vsttypes_8h.html#a81da5801773d5e380b67d049650b72b4", null ],
    [ "VST_3_7_10_VERSION", "vsttypes_8h.html#adc77fadc46f7777596d41e72746f2f93", null ],
    [ "VST_3_7_9_VERSION", "vsttypes_8h.html#a100b1e2c5665d6ea27ec0282bf555f7f", null ],
    [ "VST_3_7_8_VERSION", "vsttypes_8h.html#ac6362f71a29ce492d4be2b4e04a6e7b1", null ],
    [ "VST_3_7_7_VERSION", "vsttypes_8h.html#a7d459f763cbfc4bc4d33603d0150ded9", null ],
    [ "VST_3_7_6_VERSION", "vsttypes_8h.html#a5f992f140fce635e98e7f8e24e5e4060", null ],
    [ "VST_3_7_5_VERSION", "vsttypes_8h.html#a33a28dcfae6b25f3b989e8842349f6f7", null ],
    [ "VST_3_7_4_VERSION", "vsttypes_8h.html#a81ab44a6e43bc152c3645744604b8f33", null ],
    [ "VST_3_7_3_VERSION", "vsttypes_8h.html#ac0c1ba872a4a52d7f88e518613dd8a59", null ],
    [ "VST_3_7_2_VERSION", "vsttypes_8h.html#a88fa809e84e96e971b4b43044b16c5f8", null ],
    [ "VST_3_7_1_VERSION", "vsttypes_8h.html#a4176eccff262ac21393276308eda6ffc", null ],
    [ "VST_3_7_0_VERSION", "vsttypes_8h.html#afe55952a58f7b7e9a5014e127c8a4140", null ],
    [ "VST_3_6_14_VERSION", "vsttypes_8h.html#a874e007d87aada7b4ce52dee9b23d3b5", null ],
    [ "VST_3_6_13_VERSION", "vsttypes_8h.html#aec86d40709894538c99ad4d71f588e31", null ],
    [ "VST_3_6_12_VERSION", "vsttypes_8h.html#ad2211be35f673907393b25457672892c", null ],
    [ "VST_3_6_11_VERSION", "vsttypes_8h.html#a90e14e7fb3c3ff67b17ca84a8080753b", null ],
    [ "VST_3_6_10_VERSION", "vsttypes_8h.html#acfa5b9c8eb7f366422d712a02ce732d1", null ],
    [ "VST_3_6_9_VERSION", "vsttypes_8h.html#a9ce6c2e5c41e1725b21109f26f92b409", null ],
    [ "VST_3_6_8_VERSION", "vsttypes_8h.html#aff4235198665103c89724bbe9013dc84", null ],
    [ "VST_3_6_7_VERSION", "vsttypes_8h.html#af93d6a0ac71c20cd90bc8948adc65fbf", null ],
    [ "VST_3_6_6_VERSION", "vsttypes_8h.html#ace15b8cbfa4c0e255d2a4886662a7a5e", null ],
    [ "VST_3_6_5_VERSION", "vsttypes_8h.html#ac55de6606e8ae2c5c1722836cabbed7b", null ],
    [ "VST_3_6_0_VERSION", "vsttypes_8h.html#a4a4c2c11ce256c43ccf8e3240cd10bcc", null ],
    [ "VST_3_5_0_VERSION", "vsttypes_8h.html#aba0780a21f237667b79111c8f7419c79", null ],
    [ "VST_3_1_0_VERSION", "vsttypes_8h.html#a4b747744c89f19d7c063f1823d533a5d", null ],
    [ "VST_3_0_0_VERSION", "vsttypes_8h.html#a6c479776692cf749f41bd7bbcb0b79cd", null ],
    [ "TChar", "vsttypes_8h.html#a9cc7040d53a88b14ecab90ffb052276d", null ],
    [ "String128", "vsttypes_8h.html#a4b750afeaca8056101ac7952543dfd47", null ],
    [ "CString", "vsttypes_8h.html#af857b729bfca1b912196dd4ff5421420", null ],
    [ "MediaType", "vsttypes_8h.html#a5f0d28213b308d786ef7a1541d88368f", null ],
    [ "BusDirection", "vsttypes_8h.html#a0dc035dac7916366d61df365731f7b63", null ],
    [ "BusType", "vsttypes_8h.html#aa6029db01759d30cfcb3504b84d5d04f", null ],
    [ "IoMode", "vsttypes_8h.html#a479361a38cb42c6a07bc6845a5801e55", null ],
    [ "UnitID", "vsttypes_8h.html#a6569c340fc68115670ee0161dd73b3ed", null ],
    [ "ParamValue", "vsttypes_8h.html#a11508dccaa352a24d0ae6585a93f4641", null ],
    [ "ParamID", "vsttypes_8h.html#a1dac5893f4a5c27f986d4e51741b544c", null ],
    [ "ProgramListID", "vsttypes_8h.html#aac31a9d9a63927ad6927f2a298888c22", null ],
    [ "CtrlNumber", "vsttypes_8h.html#aa67d0906fec66282a0c9488cb52162f6", null ],
    [ "TQuarterNotes", "vsttypes_8h.html#abf70aac64179b2b47bd877600a2e8c28", null ],
    [ "TSamples", "vsttypes_8h.html#ad2e841097395dbff119029f4684dad8f", null ],
    [ "ColorSpec", "vsttypes_8h.html#a5b13d028fba1eee386ec9ac208c6238d", null ],
    [ "Sample32", "vsttypes_8h.html#a353ad4086d31e4b7c57c9124965379a6", null ],
    [ "Sample64", "vsttypes_8h.html#a8887669e1feb9270b120bcd725d0d4c1", null ],
    [ "SampleRate", "vsttypes_8h.html#a11249ca544d179e7fa61b2200a092407", null ],
    [ "SpeakerArrangement", "vsttypes_8h.html#a54884a26d0b6dfa18eb919ea004775ac", null ],
    [ "Speaker", "vsttypes_8h.html#a7a9fc6561fe897989fa3cea09ebb3250", null ]
];